==> igniteui-react-charts-16.6.4.tgz: package/ES5/PolarAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES5/UnknownValuePlotting";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { Type, enumGetBox, markType, Point_$type } from "igniteui-react-core/ES5/type";
import { List$1 } from "igniteui-react-core/ES5/List$1";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Path } from "igniteui-react-core/ES5/Path";
import { Color } from "igniteui-react-core/ES5/Color";
var PolarAreaSeries = /** @class */ (function (_super) {
    tslib_1.__extends(PolarAreaSeries, _super);
    function PolarAreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarAreaSeries.$;
        return _this;
    }
    PolarAreaSeries.prototype.bf = function () {
        return new PolarAreaSeriesView(this);
    };
    PolarAreaSeries.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.o4 = a;
    };
    PolarAreaSeries.prototype.o2 = function (a) {
        var b = a;
        b.c0();
    };
    PolarAreaSeries.prototype.o3 = function (a, b) {
        if (a.m.count > 0) {
            var c = a.m._inner[0];
            var d = a.m._inner[a.m.count - 1];
            var e = c.x == d.x && c.y == d.y;
            if (!e) {
                a.m.add(a.m._inner[0]);
            }
        }
        var f = b;
        f.c3._opacity = this.d2;
        f.c1(a.m, this.eq);
    };
    PolarAreaSeries.prototype.get_oz = function () {
        return true;
    };
    PolarAreaSeries.prototype.ou = function () {
        return this.o5;
    };
    PolarAreaSeries.$t = markType(PolarAreaSeries, 'PolarAreaSeries', PolarLineSeriesBase.$);
    return PolarAreaSeries;
}(PolarLineSeriesBase));
export { PolarAreaSeries };
Type.dep(DependencyProperty, PropertyMetadata, PolarAreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting:o5:o7', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
var PolarAreaSeriesView = /** @class */ (function (_super) {
    tslib_1.__extends(PolarAreaSeriesView, _super);
    function PolarAreaSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.cz = null;
        _this.c4 = new Path();
        _this.c2 = new Path();
        _this.cz = a;
        return _this;
    }
    PolarAreaSeriesView.prototype.ap = function () {
        _super.prototype.ap.call(this);
        if (!this.n) {
            this.e.bj = 1;
        }
    };
    Object.defineProperty(PolarAreaSeriesView.prototype, "c3", {
        get: function () {
            return this.c2;
        },
        enumerable: true,
        configurable: true
    });
    PolarAreaSeriesView.prototype.c0 = function () {
        this.c2.aj = null;
        this.c4.aj = null;
        this.an();
    };
    PolarAreaSeriesView.prototype.c1 = function (a, b) {
        var c = new List$1(Point_$type, 1, a);
        this.cz.or.d(this.c4, c, b);
        this.cz.or.d(this.c2, c, b);
        this.an();
    };
    PolarAreaSeriesView.prototype.a8 = function () {
        _super.prototype.a8.call(this);
        this.c4._stroke = this.e.kv;
        this.c4.ac = this.e.eu;
        this.c4.ai = this.e.k2;
        this.c4.ad = this.e.k3;
        this.c2._fill = this.e.ku;
        this.c2._opacity = this.e.d2;
    };
    PolarAreaSeriesView.prototype.a9 = function () {
        _super.prototype.a9.call(this);
        var a = this.bl();
        this.c4._stroke = a;
        this.c4.ac = this.e.eu + 3;
        this.c2._fill = a;
        this.c2._opacity = 1;
    };
    PolarAreaSeriesView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (a.d) {
            a.s(this.c2);
            a.s(this.c4);
        }
    };
    PolarAreaSeriesView.prototype.ai = function (a) {
        _super.prototype.ai.call(this, a);
        this.e.a2.exportPathData(a, this.c4, "polarShape", ["Main"]);
        this.e.a2.exportPathData(a, this.c2, "fillShape", ["Fill"]);
    };
    PolarAreaSeriesView.prototype.ac = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k1 = a;
        this.e.er = 5;
        this.e.es = 5;
        this.e.et = 5;
    };
    PolarAreaSeriesView.$t = markType(PolarAreaSeriesView, 'PolarAreaSeriesView', PolarLineSeriesBaseView.$);
    return PolarAreaSeriesView;
}(PolarLineSeriesBaseView));
export { PolarAreaSeriesView };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/PolarAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES5/UnknownValuePlotting";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { Type, enumGetBox, markType, Point_$type } from "igniteui-react-core/ES5/type";
import { List$1 } from "igniteui-react-core/ES5/List$1";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Path } from "igniteui-react-core/ES5/Path";
import { Color } from "igniteui-react-core/ES5/Color";
/**
 * @hidden
 */
var PolarAreaSeries = /** @class */ (function (_super) {
    tslib_1.__extends(PolarAreaSeries, _super);
    function PolarAreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarAreaSeries.$;
        return _this;
    }
    PolarAreaSeries.prototype.bf = function () {
        return new PolarAreaSeriesView(this);
    };
    PolarAreaSeries.prototype.im = function (a) {
        _super.prototype.im.call(this, a);
        this.o6 = a;
    };
    PolarAreaSeries.prototype.o4 = function (a) {
        var b = a;
        b.c0();
    };
    PolarAreaSeries.prototype.o5 = function (a, b) {
        if (a.m.count > 0) {
            var c = a.m._inner[0];
            var d = a.m._inner[a.m.count - 1];
            var e = c.x == d.x && c.y == d.y;
            if (!e) {
                a.m.add(a.m._inner[0]);
            }
        }
        var f = b;
        f.c3._opacity = this.d3;
        f.c1(a.m, this.er);
    };
    PolarAreaSeries.prototype.get_o1 = function () {
        return true;
    };
    PolarAreaSeries.prototype.ow = function () {
        return this.o7;
    };
    PolarAreaSeries.$t = markType(PolarAreaSeries, 'PolarAreaSeries', PolarLineSeriesBase.$);
    return PolarAreaSeries;
}(PolarLineSeriesBase));
export { PolarAreaSeries };
Type.dep(DependencyProperty, PropertyMetadata, PolarAreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting:o7:o9', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
/**
 * @hidden
 */
var PolarAreaSeriesView = /** @class */ (function (_super) {
    tslib_1.__extends(PolarAreaSeriesView, _super);
    function PolarAreaSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.cz = null;
        _this.c4 = new Path();
        _this.c2 = new Path();
        _this.cz = a;
        return _this;
    }
    PolarAreaSeriesView.prototype.ap = function () {
        _super.prototype.ap.call(this);
        if (!this.n) {
            this.e.bj = 1;
        }
    };
    Object.defineProperty(PolarAreaSeriesView.prototype, "c3", {
        get: function () {
            return this.c2;
        },
        enumerable: true,
        configurable: true
    });
    PolarAreaSeriesView.prototype.c0 = function () {
        this.c2.aj = null;
        this.c4.aj = null;
        this.an();
    };
    PolarAreaSeriesView.prototype.c1 = function (a, b) {
        var c = new List$1(Point_$type, 1, a);
        this.cz.ot.d(this.c4, c, b);
        this.cz.ot.d(this.c2, c, b);
        this.an();
    };
    PolarAreaSeriesView.prototype.a8 = function () {
        _super.prototype.a8.call(this);
        this.c4._stroke = this.e.kx;
        this.c4.ac = this.e.ev;
        this.c4.ai = this.e.k4;
        this.c4.ad = this.e.k5;
        this.c2._fill = this.e.kw;
        this.c2._opacity = this.e.d3;
    };
    PolarAreaSeriesView.prototype.a9 = function () {
        _super.prototype.a9.call(this);
        var a = this.bl();
        this.c4._stroke = a;
        this.c4.ac = this.e.ev + 3;
        this.c2._fill = a;
        this.c2._opacity = 1;
    };
    PolarAreaSeriesView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (a.d) {
            a.s(this.c2);
            a.s(this.c4);
        }
    };
    PolarAreaSeriesView.prototype.ai = function (a) {
        _super.prototype.ai.call(this, a);
        this.e.a2.exportPathData(a, this.c4, "polarShape", ["Main"]);
        this.e.a2.exportPathData(a, this.c2, "fillShape", ["Fill"]);
    };
    PolarAreaSeriesView.prototype.ac = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k3 = a;
        this.e.es = 5;
        this.e.et = 5;
        this.e.eu = 5;
    };
    PolarAreaSeriesView.$t = markType(PolarAreaSeriesView, 'PolarAreaSeriesView', PolarLineSeriesBaseView.$);
    return PolarAreaSeriesView;
}(PolarLineSeriesBaseView));
export { PolarAreaSeriesView };
